# blurpy

![](icon/icon.png)

[![PyPI - Version](https://img.shields.io/pypi/v/blurpy.svg)](https://pypi.org/project/blurpy)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/blurpy.svg)](https://pypi.org/project/blurpy)
![FFmpeg Support](https://img.shields.io/badge/FFmpeg-required-blue?logo=ffmpeg)
![VapourSynth](https://img.shields.io/badge/VapourSynth-%F0%9F%A7%AA_required-purple?style=flat-square&logoColor=white&color=purple)

-----

## Table of Contents

- [Requirements](#requirements)
- [Installation](#installation)
- [License](#license)

## Requirements

- **FFmpeg**
- **VapourSynth**
- **Binaries**: Get them at https://drive.google.com/file/d/1ish5yWMUsQNZ68SFuKtDrQgrcIOVyy5T/view?usp=sharing

## Installation

```console
pip install blurpy
```

Extract binaries and move them to root, ENJOY!!!

## Quickstart

```
from blurpy.blur import blur

blur(input_: str, output: str = "output.mp4", config_loc: str)
```

Fill in these as per as your own wish!

## License

`blurpy` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
